@@ -50,8 +50,8 @@ pa_evaluate <- function(p, a, model=NULL, x=NULL, tr, ...) {
 			a <- predict(model, a, ...)
 		}
 	}
-	p <- stats::na.omit(p)
-	a <- stats::na.omit(a)
+	p <- as.numeric(stats::na.omit(p))
+	a <- as.numeric(stats::na.omit(a))
 	np <- length(p)
 	na <- length(a)
 	if (na == 0 | np == 0) {
@@ -237,3 +237,31 @@ setMethod('threshold', signature(x='paModelEvaluation'),
 )
 
 
+
+
+cm_evaluate <- function(cmat, stat="overall") {
+
+	stopifnot(stat %in% c("kappa", "overall", "class"))
+	n <- sum(cmat)
+	d <- diag(cmat)
+	if (stat == "kappa") {
+		# observed (true) cases per class
+		p <- rowSums(cmat) / n 
+		# predicted cases per class
+		q <- colSums(cmat) / n 
+		expAccuracy <- sum(p*q)
+		OA <- sum(d) / n
+		kappa <- (OA - expAccuracy) / (1 - expAccuracy)
+		return(kappa)
+	} else if (stat == "overall") {
+		OA <- sum(d) / n
+		return(OA)
+	} else if (stat == "class") {
+		rw <- d / rowSums(cmat) 
+		cw <- d / colSums(cmat) 
+		x <- rbind(rw, cw)
+		rownames(x) <- c("row-wise", "col-wise")
+		return(x)
+	}
+}
+
